@@ -89,9 +89,15 @@
 	if(standardize) {
 
     if(sparse.data) {
+
       x.scale <- sqrt(colMeans(x*x) - colMeans(x)^2)
+      # Handel constant columns
+      x.scale[x.scale == 0] <- 1
+
       x.center <- rep(0, length(x.scale))
+
       x <- x%*%Diagonal(x=1/x.scale)
+
     } else {
       x <- scale(x, TRUE, TRUE)
       x.scale <- attr(x, "scaled:scale")
@@ -101,6 +107,10 @@
     if(sum(is.na(x)) > 0) {
       stop("x contains NA values after standardization, try 'standardize = FALSE'")
     }
+
+    if(sum(is.infinite(x)) > 0) {
+      stop("x contains Inf values after standardization, remove constant columns")
+    }
 	}
 
   if(intercept) {
@@ -108,18 +118,18 @@
     # add intercept
 
     if( is.null(colnames(x)) ) {
-		  x <- cBind(rep(1, nrow(x)), x)
+		  x <- cbind(rep(1, nrow(x)), x)
 	  } else {
-		  x <- cBind(Intercept = rep(1, nrow(x)), x)
+		  x <- cbind(Intercept = rep(1, nrow(x)), x)
 	  }
 
     groupWeights <- c(0, groupWeights)
 
 
     if( is.null(colnames(parameterWeights)) ) {
-      parameterWeights <- cBind(rep(0, length(levels(classes))), parameterWeights)
+      parameterWeights <- cbind(rep(0, length(levels(classes))), parameterWeights)
     } else {
-      parameterWeights <- cBind(Intercept = rep(0, length(levels(classes))), parameterWeights)
+      parameterWeights <- cbind(Intercept = rep(0, length(levels(classes))), parameterWeights)
     }
 
     grouping <- factor(c("Intercept", as.character(grouping)), levels = c("Intercept", levels(grouping)))
@@ -157,7 +167,7 @@ return(setup)
 
 }
 
-# Match with MODULE_NAME in logitsgl.cpp
+# Match with MODULE_NAME in msgl.cpp
 .get_callsym <- function(data) {
 
   obj <- "msgl"
